#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger
version:              1.52.1
visibility:           public
id:                   hledger-1.52.1-8VRHl6DMSgI7cd8NF1ZJsX
key:                  hledger-1.52.1-8VRHl6DMSgI7cd8NF1ZJsX
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting system
description:
    The command-line interface for the hledger accounting system.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance, Console
abi:                  11e9dc99dc2812bbd16f834b9597beec
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anchor Hledger.Cli.Anon
    Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Aregister
    Hledger.Cli.Commands.Balance Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Check
    Hledger.Cli.Commands.Close Hledger.Cli.Commands.Codes
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Demo
    Hledger.Cli.Commands.Descriptions Hledger.Cli.Commands.Diff
    Hledger.Cli.Commands.Files Hledger.Cli.Commands.Help
    Hledger.Cli.Commands.Import Hledger.Cli.Commands.Incomestatement
    Hledger.Cli.Commands.Notes Hledger.Cli.Commands.Payees
    Hledger.Cli.Commands.Prices Hledger.Cli.Commands.Print
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Rewrite
    Hledger.Cli.Commands.Roi Hledger.Cli.Commands.Run
    Hledger.Cli.Commands.Setup Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.Conf Hledger.Cli.DocFiles Hledger.Cli.Script
    Hledger.Cli.Utils Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.52.1-8VRHl6DMSgI7cd8NF1ZJsX
depends:
    Decimal-0.5.2-Civ14aU7Mi2Ke3ya3hZ6tj Diff-1.0-n0RmXNQVFrGyP2VCRbod4
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG
    ansi-terminal-1.1-9hyTCG9puEj4dnXsh6uh7k base-4.18.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    directory-1.3.8.5 extra-1.7.16-JQjr8PVpkEB4amK6gdUMOF
    filepath-1.4.300.1 githash-0.1.7.0-Fg8yc7ROXwtL5yKInFIZ
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg haskeline-0.8.2.1
    hledger-lib-1.52.1-8WTfduK4i2t5G8GcXTtkUW
    http-client-0.7.19-EUgGdw3KTvRKxRF4wbGFhk
    http-types-0.12.4-1B8W97d7Bm7JkBvipzT6Xa
    lucid-2.11.20260427-JjJUhnUt6qGKNKxSk9iUzh
    math-functions-0.3.4.4-K0uX50LOve9HD1fteXEiYE
    megaparsec-9.7.1-3v9USGunK8PJV50Lxdl0PB
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    modern-uri-0.3.6.1-4ek46rTK1Nf4EabRXSeXwo mtl-2.3.1
    process-1.6.19.0 regex-tdfa-1.3.2.5-7A9AvRIGkk4HgHOwz4zjio
    req-3.13.4-EZCCV6GIRhK6mB3iWvPifp
    safe-0.3.21-KdE8f1g6p6v53Pxmzg6oHI
    shakespeare-2.2.0-6aX5U9tFVlULMX2cpB9K4B
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl
    tabular-0.2.2.8-Ly9fepE9sHFB2l1Bgv9bkV
    tasty-1.5.4-HqPE37sg7IfLt8RoOq2iQG
    temporary-1.3-6srFELH6ZJ85EWwSBp1olQ text-2.0.2
    text-ansi-0.3.0.1-5wE7Rlev9Ij3sMAMYKGfs8 time-1.12.2
    timeit-2.0-DwmItJuhuSm6aktMh1S1ZM transformers-0.6.1.0
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    utility-ht-0.0.17.2-BnpWfvJGSUB9uqUtFXXsCk
    wizards-1.0.3-EMndOhiYuHdGTEqrX5mo0v

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

